@@ -13,7 +13,7 @@ import random
 import uuid
 import copy
 import serpentmonkee.UtilsMonkee as um
-from neo4j.exceptions import CypherSyntaxError, ServiceUnavailable, ClientError
+from neo4j.exceptions import CypherSyntaxError, ServiceUnavailable, ClientError, ConstraintError
 from serpentmonkee.PubSubMonkee import PubSubMonkee
 import logging
 # --------------------------------------------------------------------
@@ -229,6 +229,22 @@ class CypherTransactionBlock:
                             ],
                         )
 
+                elif newState == 'givenUp':
+                    sqlQuery = (
+                        """ UPDATE """ + self.qTable + """ 
+                        SET errors = %s||'  '||errors
+                        WHERE q_uid = %s"""
+                    )
+                    with self.sqlClient.connect() as conn:
+                        conn.execute(
+                            sqlQuery,
+                            [
+                                error,
+                                self.transactionUid
+
+                            ],
+                        )
+
                 elif newState == 'outOfWorkingQ':
                     sqlQuery = (
                         """ UPDATE """ + self.qTable + """ 
@@ -421,6 +437,26 @@ class CypherTransactionBlockWorker:
                 ctBlock.registerChangeInSql('error', repr(e))
                 return False
 
+            except ConstraintError as e:
+                print('ConstraintError')
+                logging.error(repr(e))
+                ctBlock.numRetries += 1
+                ctBlock.status = 'ConstraintError'
+                ctBlock.errors = repr(e)
+                rem = self.removeBlockFromWorkingQueue(matchingSerial)
+                if rem > 0:
+                    ctBlock.registerChangeInSql('outOfWorkingQ')
+                ctBlock.setJson()
+                if ctBlock.numRetries <= 50:
+                    print(f'>>>>ctBlock.numRetries={ctBlock.numRetries}')
+                    self.cypherQueues.pushCtbToWaitingQ(ctBlock)
+                    ctBlock.registerChangeInSql('error', repr(e))
+                else:
+                    self.cypherQueues.pushCtbToCompletedQ(ctBlock)
+                    ctBlock.registerChangeInSql('givenUp', 'GIVEN UP')
+
+                return False
+
             except ClientError as e:
                 print('ClientError')
                 logging.error(repr(e))
